%define major		1
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Name:		blosc
Version:	1.21.5
Release:	%mkrel 1
Summary:	A blocking, shuffling and lossless compression library
License:	MIT
Group:		System/Libraries
URL:		https://www.blosc.org/
Source0:	https://github.com/Blosc/c-blosc/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(snappy)
BuildRequires:	pkgconfig(zlib)

%description
Blosc is a compressor for binary data, designed to transmit data to
the processor cache faster than the traditional, non-compressed,
direct memory fetch approach via a memcpy() call. Blosc is not only a
compressor for data size reduction, but also for accelerating
memory-bound computations.

It uses the blocking technique to reduce activity on the memory bus,
which works by dividing datasets in blocks that are small enough to
fit in caches of processors and perform (de)compression there. SIMD
and multi-threading capabilities are leveraged if available.

Blosc is a metacompressor; it can use different compression
algorithms, such as BloscLZ, LZ4, LZ4HC, Snappy and Zlib.

%package -n	%{libname}
Summary:	A blocking, shuffling and lossless compression library
Group:		System/Libraries

%description -n	%{libname}
Blosc is a metacompressor (using actual algorithms like BloscLZ, LZ4,
LZ4HC, Snappy or Zlib) for binary data, with a focus on reducing
memory bus activity.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for developing
applications that use %{name}.

%prep
%setup -q -n c-blosc-%{version}
%autopatch -p1

# https://github.com/Blosc/c-blosc/issues/190
sed -i 's|lib/pkgconfig|%{_lib}/pkgconfig|' CMakeLists.txt

%build
%cmake \
	-DBUILD_STATIC=OFF \
	-DBUILD_FUZZERS=OFF \
	-DCMAKE_C_FLAGS:STRING="%{optflags}" \
	-DPREFER_EXTERNAL_SNAPPY=ON \
	-DPREFER_EXTERNAL_ZLIB=ON \
	-DPREFER_EXTERNAL_ZSTD=ON \
	-DPREFER_EXTERNAL_LZ4=ON
%cmake_build

%install
%cmake_install

%files -n %{libname}
%doc ANNOUNCE.rst README.md README_THREADED.rst RELEASE_NOTES.rst THANKS.rst
%license LICENSES/*.txt
%{_libdir}/libblosc.so.%{major}
%{_libdir}/libblosc.so.%{version}

%files -n %{develname}
%doc README.md
%doc examples/
%{_includedir}/blosc.h
%{_includedir}/blosc-export.h
%{_libdir}/libblosc.so
%{_libdir}/pkgconfig/blosc.pc


%changelog
* Tue Sep 19 2023 daviddavid <daviddavid> 1.21.5-1.mga10
+ Revision: 1987997
- new version: 1.21.5

* Mon Aug 28 2023 daviddavid <daviddavid> 1.21.4-1.mga10
+ Revision: 1980326
- new version: 1.21.4

* Tue Jan 03 2023 daviddavid <daviddavid> 1.21.2-1.mga9
+ Revision: 1929695
- new version: 1.21.2

* Sat Sep 10 2022 neoclust <neoclust> 1.21.1-1.mga9
+ Revision: 1886617
- New version 1.21.1

* Wed Mar 30 2022 umeabot <umeabot> 1.21.0-2.mga9
+ Revision: 1834124
- Mageia 9 Mass Rebuild

* Thu Dec 24 2020 daviddavid <daviddavid> 1.21.0-1.mga8
+ Revision: 1663412
- new version: 1.21.0

* Fri Sep 11 2020 daviddavid <daviddavid> 1.20.1-1.mga8
+ Revision: 1624641
- new version: 1.20.1

* Sun Aug 02 2020 daviddavid <daviddavid> 1.20.0-1.mga8
+ Revision: 1610560
- new version: 1.20.0

* Sat Jun 06 2020 daviddavid <daviddavid> 1.19.0-1.mga8
+ Revision: 1590717
- new version: 1.19.0

* Tue Mar 31 2020 daviddavid <daviddavid> 1.18.1-1.mga8
+ Revision: 1562567
- new version: 1.18.1

* Tue Feb 18 2020 umeabot <umeabot> 1.17.1-2.mga8
+ Revision: 1541257
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Dec 22 2019 daviddavid <daviddavid> 1.17.1-1.mga8
+ Revision: 1469432
- new version: 1.17.1

* Fri Jul 26 2019 daviddavid <daviddavid> 1.17.0-1.mga8
+ Revision: 1424191
- new version: 1.17.0

* Mon Mar 11 2019 daviddavid <daviddavid> 1.16.3-1.mga7
+ Revision: 1373919
- new version: 1.16.3

* Mon Feb 04 2019 daviddavid <daviddavid> 1.16.2-1.mga7
+ Revision: 1363129
- new version: 1.16.2

* Fri Jan 04 2019 daviddavid <daviddavid> 1.15.1-1.mga7
+ Revision: 1348995
- new version: 1.15.1

* Sun Dec 02 2018 daviddavid <daviddavid> 1.15.0-1.mga7
+ Revision: 1337615
- new version: 1.15.0

* Fri Sep 21 2018 umeabot <umeabot> 1.14.4-2.mga7
+ Revision: 1295546
- Mageia 7 Mass Rebuild

* Fri Aug 03 2018 daviddavid <daviddavid> 1.14.4-1.mga7
+ Revision: 1246989
- new version: 1.14.4

* Mon Apr 09 2018 daviddavid <daviddavid> 1.14.3-1.mga7
+ Revision: 1216400
- new version: 1.14.3

* Sat Mar 24 2018 daviddavid <daviddavid> 1.14.2-1.mga7
+ Revision: 1211833
- initial package blosc

